.. image:: https://travis-ci.org/david-caro/python-autosemver.svg?branch=master
    :target: https://travis-ci.org/david-caro/python-autosemver

===========
Autosemver
===========

Tools to handle automatic semantic versioning in python

Full documentation here: http://autosemver.readthedocs.io

